# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/update_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/update_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import offset_checkpoint_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_offset__checkpoint__pb2
from . import reassignment_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__pb2
from . import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+com/daml/ledger/api/v2/update_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a.com/daml/ledger/api/v2/offset_checkpoint.proto\x1a)com/daml/ledger/api/v2/reassignment.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\"\xd5\x01\n\x11GetUpdatesRequest\x12\'\n\x0f\x62\x65gin_exclusive\x18\x01 \x01(\x03R\x0e\x62\x65ginExclusive\x12(\n\rend_inclusive\x18\x02 \x01(\x03H\x00R\x0c\x65ndInclusive\x88\x01\x01\x12\x41\n\x06\x66ilter\x18\x03 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFilterR\x06\x66ilter\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verboseB\x10\n\x0e_end_inclusive\"\x8c\x02\n\x12GetUpdatesResponse\x12G\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionH\x00R\x0btransaction\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12W\n\x11offset_checkpoint\x18\x03 \x01(\x0b\x32(.com.daml.ledger.api.v2.OffsetCheckpointH\x00R\x10offsetCheckpointB\x08\n\x06update\"\x9d\x02\n\x16GetUpdateTreesResponse\x12T\n\x10transaction_tree\x18\x01 \x01(\x0b\x32\'.com.daml.ledger.api.v2.TransactionTreeH\x00R\x0ftransactionTree\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12W\n\x11offset_checkpoint\x18\x03 \x01(\x0b\x32(.com.daml.ledger.api.v2.OffsetCheckpointH\x00R\x10offsetCheckpointB\x08\n\x06update\"j\n\x1eGetTransactionByEventIdRequest\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12-\n\x12requesting_parties\x18\x02 \x03(\tR\x11requestingParties\"g\n\x19GetTransactionByIdRequest\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12-\n\x12requesting_parties\x18\x02 \x03(\tR\x11requestingParties\"g\n\x1aGetTransactionTreeResponse\x12I\n\x0btransaction\x18\x01 \x01(\x0b\x32\'.com.daml.ledger.api.v2.TransactionTreeR\x0btransaction\"_\n\x16GetTransactionResponse\x12\x45\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionR\x0btransaction2\xef\x05\n\rUpdateService\x12\x65\n\nGetUpdates\x12).com.daml.ledger.api.v2.GetUpdatesRequest\x1a*.com.daml.ledger.api.v2.GetUpdatesResponse0\x01\x12m\n\x0eGetUpdateTrees\x12).com.daml.ledger.api.v2.GetUpdatesRequest\x1a..com.daml.ledger.api.v2.GetUpdateTreesResponse0\x01\x12\x89\x01\n\x1bGetTransactionTreeByEventId\x12\x36.com.daml.ledger.api.v2.GetTransactionByEventIdRequest\x1a\x32.com.daml.ledger.api.v2.GetTransactionTreeResponse\x12\x7f\n\x16GetTransactionTreeById\x12\x31.com.daml.ledger.api.v2.GetTransactionByIdRequest\x1a\x32.com.daml.ledger.api.v2.GetTransactionTreeResponse\x12\x81\x01\n\x17GetTransactionByEventId\x12\x36.com.daml.ledger.api.v2.GetTransactionByEventIdRequest\x1a..com.daml.ledger.api.v2.GetTransactionResponse\x12w\n\x12GetTransactionById\x12\x31.com.daml.ledger.api.v2.GetTransactionByIdRequest\x1a..com.daml.ledger.api.v2.GetTransactionResponseB\x91\x01\n\x16\x63om.daml.ledger.api.v2B\x17UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.update_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\027UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_GETUPDATESREQUEST']._serialized_start=254
  _globals['_GETUPDATESREQUEST']._serialized_end=467
  _globals['_GETUPDATESRESPONSE']._serialized_start=470
  _globals['_GETUPDATESRESPONSE']._serialized_end=738
  _globals['_GETUPDATETREESRESPONSE']._serialized_start=741
  _globals['_GETUPDATETREESRESPONSE']._serialized_end=1026
  _globals['_GETTRANSACTIONBYEVENTIDREQUEST']._serialized_start=1028
  _globals['_GETTRANSACTIONBYEVENTIDREQUEST']._serialized_end=1134
  _globals['_GETTRANSACTIONBYIDREQUEST']._serialized_start=1136
  _globals['_GETTRANSACTIONBYIDREQUEST']._serialized_end=1239
  _globals['_GETTRANSACTIONTREERESPONSE']._serialized_start=1241
  _globals['_GETTRANSACTIONTREERESPONSE']._serialized_end=1344
  _globals['_GETTRANSACTIONRESPONSE']._serialized_start=1346
  _globals['_GETTRANSACTIONRESPONSE']._serialized_end=1441
  _globals['_UPDATESERVICE']._serialized_start=1444
  _globals['_UPDATESERVICE']._serialized_end=2195
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IdentityProviderConfig(_message.Message):
    __slots__ = ("identity_provider_id", "is_deactivated", "issuer", "jwks_url", "audience")
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    IS_DEACTIVATED_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    JWKS_URL_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    identity_provider_id: str
    is_deactivated: bool
    issuer: str
    jwks_url: str
    audience: str
    def __init__(self, identity_provider_id: _Optional[str] = ..., is_deactivated: bool = ..., issuer: _Optional[str] = ..., jwks_url: _Optional[str] = ..., audience: _Optional[str] = ...) -> None: ...

class CreateIdentityProviderConfigRequest(_message.Message):
    __slots__ = ("identity_provider_config",)
    IDENTITY_PROVIDER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    identity_provider_config: IdentityProviderConfig
    def __init__(self, identity_provider_config: _Optional[_Union[IdentityProviderConfig, _Mapping]] = ...) -> None: ...

class CreateIdentityProviderConfigResponse(_message.Message):
    __slots__ = ("identity_provider_config",)
    IDENTITY_PROVIDER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    identity_provider_config: IdentityProviderConfig
    def __init__(self, identity_provider_config: _Optional[_Union[IdentityProviderConfig, _Mapping]] = ...) -> None: ...

class GetIdentityProviderConfigRequest(_message.Message):
    __slots__ = ("identity_provider_id",)
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    identity_provider_id: str
    def __init__(self, identity_provider_id: _Optional[str] = ...) -> None: ...

class GetIdentityProviderConfigResponse(_message.Message):
    __slots__ = ("identity_provider_config",)
    IDENTITY_PROVIDER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    identity_provider_config: IdentityProviderConfig
    def __init__(self, identity_provider_config: _Optional[_Union[IdentityProviderConfig, _Mapping]] = ...) -> None: ...

class ListIdentityProviderConfigsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListIdentityProviderConfigsResponse(_message.Message):
    __slots__ = ("identity_provider_configs",)
    IDENTITY_PROVIDER_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    identity_provider_configs: _containers.RepeatedCompositeFieldContainer[IdentityProviderConfig]
    def __init__(self, identity_provider_configs: _Optional[_Iterable[_Union[IdentityProviderConfig, _Mapping]]] = ...) -> None: ...

class UpdateIdentityProviderConfigRequest(_message.Message):
    __slots__ = ("identity_provider_config", "update_mask")
    IDENTITY_PROVIDER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    identity_provider_config: IdentityProviderConfig
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, identity_provider_config: _Optional[_Union[IdentityProviderConfig, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdateIdentityProviderConfigResponse(_message.Message):
    __slots__ = ("identity_provider_config",)
    IDENTITY_PROVIDER_CONFIG_FIELD_NUMBER: _ClassVar[int]
    identity_provider_config: IdentityProviderConfig
    def __init__(self, identity_provider_config: _Optional[_Union[IdentityProviderConfig, _Mapping]] = ...) -> None: ...

class DeleteIdentityProviderConfigRequest(_message.Message):
    __slots__ = ("identity_provider_id",)
    IDENTITY_PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    identity_provider_id: str
    def __init__(self, identity_provider_id: _Optional[str] = ...) -> None: ...

class DeleteIdentityProviderConfigResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import event_pb2 as _event_pb2
from . import transaction_filter_pb2 as _transaction_filter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetActiveContractsRequest(_message.Message):
    __slots__ = ("ledger_id", "filter", "verbose", "active_at_offset")
    LEDGER_ID_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_AT_OFFSET_FIELD_NUMBER: _ClassVar[int]
    ledger_id: str
    filter: _transaction_filter_pb2.TransactionFilter
    verbose: bool
    active_at_offset: str
    def __init__(self, ledger_id: _Optional[str] = ..., filter: _Optional[_Union[_transaction_filter_pb2.TransactionFilter, _Mapping]] = ..., verbose: bool = ..., active_at_offset: _Optional[str] = ...) -> None: ...

class GetActiveContractsResponse(_message.Message):
    __slots__ = ("offset", "workflow_id", "active_contracts")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    offset: str
    workflow_id: str
    active_contracts: _containers.RepeatedCompositeFieldContainer[_event_pb2.CreatedEvent]
    def __init__(self, offset: _Optional[str] = ..., workflow_id: _Optional[str] = ..., active_contracts: _Optional[_Iterable[_Union[_event_pb2.CreatedEvent, _Mapping]]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from google.protobuf.empty_pb2 import Empty
from grpc import aio as _grpc_aio

from .sequencer_service_pb2 import AcknowledgeRequest, SendAsyncResponse, SendAsyncSignedResponse, SendAsyncUnauthenticatedVersionedRequest, SendAsyncVersionedRequest, SubscriptionRequest, SubscriptionResponse, VersionedSubscriptionResponse
from ....protocol.v0.sequencing_pb2 import SignedContent, SubmissionRequest

__all__ = [
    "SequencerServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerServiceAsyncStub: ...  # type: ignore
    def SendAsync(self, __1: SubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SendAsyncResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncResponse]]: ...
    def SendAsyncSigned(self, __1: SignedContent, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SendAsyncSignedResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncSignedResponse]]: ...
    def SendAsyncUnauthenticated(self, __1: SubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SendAsyncResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncResponse]]: ...
    def SendAsyncVersioned(self, __1: SendAsyncVersionedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SendAsyncSignedResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncSignedResponse]]: ...
    def SendAsyncUnauthenticatedVersioned(self, __1: SendAsyncUnauthenticatedVersionedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SendAsyncResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncResponse]]: ...
    def Subscribe(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[SubscriptionResponse], _grpc_aio.UnaryStreamCall[_typing.Any, SubscriptionResponse]]: ...
    def SubscribeVersioned(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[VersionedSubscriptionResponse], _grpc_aio.UnaryStreamCall[_typing.Any, VersionedSubscriptionResponse]]: ...
    def SubscribeUnauthenticated(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[SubscriptionResponse], _grpc_aio.UnaryStreamCall[_typing.Any, SubscriptionResponse]]: ...
    def SubscribeUnauthenticatedVersioned(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[VersionedSubscriptionResponse], _grpc_aio.UnaryStreamCall[_typing.Any, VersionedSubscriptionResponse]]: ...
    def Acknowledge(self, __1: AcknowledgeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[Empty, _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]]: ...
    def AcknowledgeSigned(self, __1: SignedContent, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[Empty, _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerServiceBlockingStub(SequencerServiceStub):
    def SendAsync(self, __1: SubmissionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SendAsyncResponse: ...
    def SendAsyncSigned(self, __1: SignedContent, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SendAsyncSignedResponse: ...
    def SendAsyncUnauthenticated(self, __1: SubmissionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SendAsyncResponse: ...
    def SendAsyncVersioned(self, __1: SendAsyncVersionedRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SendAsyncSignedResponse: ...
    def SendAsyncUnauthenticatedVersioned(self, __1: SendAsyncUnauthenticatedVersionedRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SendAsyncResponse: ...
    def Subscribe(self, __1: SubscriptionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[SubscriptionResponse]: ...
    def SubscribeVersioned(self, __1: SubscriptionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[VersionedSubscriptionResponse]: ...
    def SubscribeUnauthenticated(self, __1: SubscriptionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[SubscriptionResponse]: ...
    def SubscribeUnauthenticatedVersioned(self, __1: SubscriptionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[VersionedSubscriptionResponse]: ...
    def Acknowledge(self, __1: AcknowledgeRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> Empty: ...
    def AcknowledgeSigned(self, __1: SignedContent, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> Empty: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerServiceAsyncStub(SequencerServiceStub):
    def SendAsync(self, __1: SubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncResponse]: ...  # type: ignore
    def SendAsyncSigned(self, __1: SignedContent, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncSignedResponse]: ...  # type: ignore
    def SendAsyncUnauthenticated(self, __1: SubmissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncResponse]: ...  # type: ignore
    def SendAsyncVersioned(self, __1: SendAsyncVersionedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncSignedResponse]: ...  # type: ignore
    def SendAsyncUnauthenticatedVersioned(self, __1: SendAsyncUnauthenticatedVersionedRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SendAsyncResponse]: ...  # type: ignore
    def Subscribe(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, SubscriptionResponse]: ...  # type: ignore
    def SubscribeVersioned(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, VersionedSubscriptionResponse]: ...  # type: ignore
    def SubscribeUnauthenticated(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, SubscriptionResponse]: ...  # type: ignore
    def SubscribeUnauthenticatedVersioned(self, __1: SubscriptionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, VersionedSubscriptionResponse]: ...  # type: ignore
    def Acknowledge(self, __1: AcknowledgeRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]: ...  # type: ignore
    def AcknowledgeSigned(self, __1: SignedContent, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, Empty]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExperimentalFeatures(_message.Message):
    __slots__ = ("static_time", "command_inspection_service", "interactive_submission_service")
    STATIC_TIME_FIELD_NUMBER: _ClassVar[int]
    COMMAND_INSPECTION_SERVICE_FIELD_NUMBER: _ClassVar[int]
    INTERACTIVE_SUBMISSION_SERVICE_FIELD_NUMBER: _ClassVar[int]
    static_time: ExperimentalStaticTime
    command_inspection_service: ExperimentalCommandInspectionService
    interactive_submission_service: ExperimentalInteractiveSubmissionService
    def __init__(self, static_time: _Optional[_Union[ExperimentalStaticTime, _Mapping]] = ..., command_inspection_service: _Optional[_Union[ExperimentalCommandInspectionService, _Mapping]] = ..., interactive_submission_service: _Optional[_Union[ExperimentalInteractiveSubmissionService, _Mapping]] = ...) -> None: ...

class ExperimentalStaticTime(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class ExperimentalCommandInspectionService(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...

class ExperimentalInteractiveSubmissionService(_message.Message):
    __slots__ = ("supported",)
    SUPPORTED_FIELD_NUMBER: _ClassVar[int]
    supported: bool
    def __init__(self, supported: bool = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .time_tracker_config_pb2 import DomainTimeTrackerConfig, TimeProofRequestConfig

__all__ = [
    "DomainTimeTrackerConfig",
    "TimeProofRequestConfig",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .daml_lf2_pb2 import Binding, Block, BuiltinCon, BuiltinFunction, BuiltinLit, BuiltinType, Case, CaseAlt, DefDataType, DefException, DefInterface, DefTemplate, DefTypeSyn, DefValue, Expr, FeatureFlags, FieldWithExpr, FieldWithType, InterfaceInstanceBody, InterfaceMethod, InternedDottedName, Kind, Location, Module, ModuleRef, Package, PackageMetadata, PackageRef, Pure, Scenario, TemplateChoice, Type, TypeConName, TypeSynName, TypeVarWithKind, Unit, Update, UpgradedPackageId, ValName, VarWithType
from .daml_lf_pb2 import Archive, ArchivePayload, HashFunction

__all__ = [
    "Archive",
    "ArchivePayload",
    "Binding",
    "Block",
    "BuiltinCon",
    "BuiltinFunction",
    "BuiltinLit",
    "BuiltinType",
    "Case",
    "CaseAlt",
    "DefDataType",
    "DefException",
    "DefInterface",
    "DefTemplate",
    "DefTypeSyn",
    "DefValue",
    "Expr",
    "FeatureFlags",
    "FieldWithExpr",
    "FieldWithType",
    "HashFunction",
    "InterfaceInstanceBody",
    "InterfaceMethod",
    "InternedDottedName",
    "Kind",
    "Location",
    "Module",
    "ModuleRef",
    "Package",
    "PackageMetadata",
    "PackageRef",
    "Pure",
    "Scenario",
    "TemplateChoice",
    "Type",
    "TypeConName",
    "TypeSynName",
    "TypeVarWithKind",
    "Unit",
    "Update",
    "UpgradedPackageId",
    "ValName",
    "VarWithType",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import topology_pb2 as _topology_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Quorum(_message.Message):
    __slots__ = ("party_index_and_weight", "threshold")
    PARTY_INDEX_AND_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    party_index_and_weight: _containers.RepeatedCompositeFieldContainer[PartyIndexAndWeight]
    threshold: int
    def __init__(self, party_index_and_weight: _Optional[_Iterable[_Union[PartyIndexAndWeight, _Mapping]]] = ..., threshold: _Optional[int] = ...) -> None: ...

class PartyIndexAndWeight(_message.Message):
    __slots__ = ("index", "weight")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    index: int
    weight: int
    def __init__(self, index: _Optional[int] = ..., weight: _Optional[int] = ...) -> None: ...

class TrustParty(_message.Message):
    __slots__ = ("party", "required_trust_level")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_TRUST_LEVEL_FIELD_NUMBER: _ClassVar[int]
    party: str
    required_trust_level: _topology_pb2.TrustLevel
    def __init__(self, party: _Optional[str] = ..., required_trust_level: _Optional[_Union[_topology_pb2.TrustLevel, str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVcom/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x1egoogle/protobuf/wrappers.proto\"o\n\x16\x41\x64\x64PeerEndpointRequest\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\"r\n\x19RemovePeerEndpointRequest\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\"6\n\x0cPeerEndpoint\x12\x12\n\x04host\x18\x01 \x01(\tR\x04host\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\"/\n\x17\x41\x64\x64PeerEndpointResponse\x12\x14\n\x05\x61\x64\x64\x65\x64\x18\x01 \x01(\x08R\x05\x61\x64\x64\x65\x64\"6\n\x1aRemovePeerEndpointResponse\x12\x18\n\x07removed\x18\x01 \x01(\x08R\x07removed\"\xb3\x01\n\x12PeerEndpointHealth\x12]\n\x06status\x18\x01 \x01(\x0e\x32\x45.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatusR\x06status\x12>\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scription\"\xc4\x01\n\x12PeerEndpointStatus\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\x12W\n\x06health\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthR\x06health\"v\n\x1bGetPeerNetworkStatusRequest\x12W\n\tendpoints\x18\x01 \x03(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\tendpoints\"{\n\x1cGetPeerNetworkStatusResponse\x12[\n\x08statuses\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointStatusR\x08statuses\"\x1c\n\x1aGetOrderingTopologyRequest\"g\n\x1bGetOrderingTopologyResponse\x12#\n\rcurrent_epoch\x18\x01 \x01(\x03R\x0c\x63urrentEpoch\x12#\n\rsequencer_ids\x18\x02 \x03(\tR\x0csequencerIds*\xd9\x01\n\x18PeerEndpointHealthStatus\x12+\n\'PEER_ENDPOINT_HEALTH_STATUS_UNSPECIFIED\x10\x00\x12\x30\n,PEER_ENDPOINT_HEALTH_STATUS_UNKNOWN_ENDPOINT\x10\x01\x12/\n+PEER_ENDPOINT_HEALTH_STATUS_UNAUTHENTICATED\x10\x03\x12-\n)PEER_ENDPOINT_HEALTH_STATUS_AUTHENTICATED\x10\x04\x32\xc3\x05\n!SequencerBftAdministrationService\x12\x9c\x01\n\x0f\x41\x64\x64PeerEndpoint\x12\x43.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointRequest\x1a\x44.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointResponse\x12\xa5\x01\n\x12RemovePeerEndpoint\x12\x46.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointRequest\x1aG.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointResponse\x12\xab\x01\n\x14GetPeerNetworkStatus\x12H.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusRequest\x1aI.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusResponse\x12\xa8\x01\n\x13GetOrderingTopology\x12G.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_bft_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_start=1319
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_end=1536
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_start=167
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_end=278
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_start=280
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_end=394
  _globals['_PEERENDPOINT']._serialized_start=396
  _globals['_PEERENDPOINT']._serialized_end=450
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_start=452
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_end=499
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_start=501
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_end=555
  _globals['_PEERENDPOINTHEALTH']._serialized_start=558
  _globals['_PEERENDPOINTHEALTH']._serialized_end=737
  _globals['_PEERENDPOINTSTATUS']._serialized_start=740
  _globals['_PEERENDPOINTSTATUS']._serialized_end=936
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_start=938
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_end=1056
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_start=1058
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_end=1181
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_start=1183
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_end=1211
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_start=1213
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_end=1316
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_start=1539
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_end=2246
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenTransactionTree(_message.Message):
    __slots__ = ("submitter_metadata", "common_metadata", "participant_metadata", "root_views")
    SUBMITTER_METADATA_FIELD_NUMBER: _ClassVar[int]
    COMMON_METADATA_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_METADATA_FIELD_NUMBER: _ClassVar[int]
    ROOT_VIEWS_FIELD_NUMBER: _ClassVar[int]
    submitter_metadata: BlindableNode
    common_metadata: BlindableNode
    participant_metadata: BlindableNode
    root_views: MerkleSeq
    def __init__(self, submitter_metadata: _Optional[_Union[BlindableNode, _Mapping]] = ..., common_metadata: _Optional[_Union[BlindableNode, _Mapping]] = ..., participant_metadata: _Optional[_Union[BlindableNode, _Mapping]] = ..., root_views: _Optional[_Union[MerkleSeq, _Mapping]] = ...) -> None: ...

class BlindableNode(_message.Message):
    __slots__ = ("unblinded", "blinded_hash")
    UNBLINDED_FIELD_NUMBER: _ClassVar[int]
    BLINDED_HASH_FIELD_NUMBER: _ClassVar[int]
    unblinded: bytes
    blinded_hash: bytes
    def __init__(self, unblinded: _Optional[bytes] = ..., blinded_hash: _Optional[bytes] = ...) -> None: ...

class MerkleSeq(_message.Message):
    __slots__ = ("root_or_empty",)
    ROOT_OR_EMPTY_FIELD_NUMBER: _ClassVar[int]
    root_or_empty: BlindableNode
    def __init__(self, root_or_empty: _Optional[_Union[BlindableNode, _Mapping]] = ...) -> None: ...

class MerkleSeqElement(_message.Message):
    __slots__ = ("first", "second", "data")
    FIRST_FIELD_NUMBER: _ClassVar[int]
    SECOND_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    first: BlindableNode
    second: BlindableNode
    data: BlindableNode
    def __init__(self, first: _Optional[_Union[BlindableNode, _Mapping]] = ..., second: _Optional[_Union[BlindableNode, _Mapping]] = ..., data: _Optional[_Union[BlindableNode, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import sys
from typing import Callable, Collection, Optional, TypedDict, TypeVar

from grpc import aio

from .. import ActAs, CommandMeta, ReadAs
from ... import Party
from ..._gen.com.daml.ledger.api import v1 as lapipb
from ..._gen.com.daml.ledger.api.v1 import admin as lapiadminpb
from .._call import CallContext as CallContextBase
from ..auth import parse_token
from .codec_aio import Codec

if sys.version_info >= (3, 11):
    from typing import assert_never
else:
    from typing_extensions import assert_never

__all__ = ["CallContext"]

T = TypeVar("T")


class GrpcKwargs(TypedDict, total=False):
    """
    Keyword arguments that should accompany a
    """

    timeout: float
    metadata: aio.Metadata


class CallContext(CallContextBase):
    """
    Contextual information as it relates to a single logical Ledger API call.
    """

    channel: Optional[aio.Channel]

    async def get_read_as(self) -> Collection[Party]:
        """
        Return all the parties that the current call is reading as.
        """
        meta = await self.command_meta()
        p = set[Party]()
        if meta.read_as is not None:
            p.update(meta.read_as)
        if meta.act_as is not None:
            p.update(meta.act_as)
        return sorted(p)

    async def get_ledger_id(self) -> str:
        if self.ledger_id is None:
            stub = self.grpc_stub(lapipb.LedgerIdentityServiceStub)
            response = await stub.GetLedgerIdentity(
                lapipb.GetLedgerIdentityRequest(), **self.grpc_kwargs
            )
            self.ledger_id = response.ledger_id

        return self.ledger_id

    async def command_meta(self) -> CommandMeta:
        """
        Return an overall :class:`CommandMeta` for the effective values of this call.
        """
        if self.read_as is None and self.act_as is None:
            if self.token:
                parsed_token = parse_token(self.token)
                if parsed_token.token_version == 1:
                    self.read_as = parsed_token.read_as
                    self.act_as = parsed_token.act_as
                    if parsed_token.ledger_id is not None:
                        self.ledger_id = parsed_token.ledger_id
                    if self.user_id_or_application_name is not None:
                        self.user_id_or_application_name = parsed_token.application_name

                elif parsed_token.token_version == 2:
                    if self.user_id_or_application_name is None:
                        self.user_id_or_application_name = parsed_token.user_id
                    elif self.user_id_or_application_name != parsed_token.user_id:
                        raise ValueError("")

                    stub = self.grpc_stub(lapiadminpb.UserManagementServiceStub)
                    request = lapiadminpb.ListUserRightsRequest(
                        user_id=self.user_id_or_application_name
                    )
                    response = await stub.ListUserRights(request, **self.grpc_kwargs)

                    read_as = set()
                    act_as = set()
                    for pb in response.rights:
                        right = Codec.decode_right(pb)
                        if isinstance(right, ActAs):
                            act_as.add(right.party)
                        elif isinstance(right, ReadAs):
                            read_as.add(right.party)
                    self.read_as = sorted(read_as)
                    self.act_as = sorted(act_as)
                else:
                    assert_never(parsed_token.token_version)

            elif self.user_id_or_application_name:
                # no token; this could be because the ledger is unauthed, or
                # perhaps there is an authenticating proxy between us and the ledger
                stub = self.grpc_stub(lapiadminpb.UserManagementServiceStub)
                request = lapiadminpb.ListUserRightsRequest(
                    user_id=self.user_id_or_application_name
                )
                response = await stub.ListUserRights(request, **self.grpc_kwargs)

                read_as = set()
                act_as = set()
                for pb in response.rights:
                    right = Codec.decode_right(pb)
                    if isinstance(right, ActAs):
                        act_as.add(right.party)
                    elif isinstance(right, ReadAs):
                        read_as.add(right.party)
                self.read_as = sorted(read_as)
                self.act_as = sorted(act_as)

            else:
                # if absolutely no identifying information at all has been supplied, there
                # simply isn't anything more that can be done
                raise ValueError(
                    "either read_as/act_as, application_name, user_id, or a token must be specified"
                )

        if self.user_id_or_application_name is None:
            # TODO: avoid double-parsing the token if we can
            if self.token is not None:
                parsed_token = parse_token(self.token)
                if parsed_token.token_version == 2:
                    self.user_id_or_application_name = parsed_token.user_id

        if self.user_id_or_application_name is None:
            # if, after all of that, we still can't default the user id, use dazl's
            # old default value
            self.user_id_or_application_name = "DAZL-Client"

        return CommandMeta(
            workflow_id=self.workflow_id,
            command_id=self.command_id,
            read_as=self.read_as,
            act_as=self.act_as,
            user_id=self.user_id_or_application_name,
        )

    def grpc_stub(self, grpc_service: Callable[[aio.Channel], T], /) -> T:
        """
        Create an async stub for the specified type.
        """
        # this really only exists because IntelliJ doesn't handle these typing rules without a
        # little bit of help; mypy correctly validates these types.
        channel = getattr(self, "channel", None)
        if channel is None:
            # an unset channel is really a coding error
            raise Exception("a channel must be set on a CallContext before use")

        return grpc_service(channel)

    @property
    def grpc_kwargs(self) -> GrpcKwargs:
        """
        Generate keyword arguments that should accompany a gRPC Ledger API call.
        """
        kwargs = GrpcKwargs()
        kwargs["timeout"] = self.timeout_seconds
        if self.token:
            kwargs["metadata"] = aio.Metadata(("authorization", f"Bearer {self.token}"))
        return kwargs


class Cache:
    pass



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/transfer_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/admin/participant/v30/transfer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDcom/digitalasset/canton/admin/participant/v30/transfer_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\nTransferId\x12#\n\rsource_domain\x18\x01 \x01(\tR\x0csourceDomain\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x86\x02\n\x18\x41\x64minTransferSearchQuery\x12#\n\rsearch_domain\x18\x01 \x01(\tR\x0csearchDomain\x12\x30\n\x14\x66ilter_origin_domain\x18\x02 \x01(\tR\x12\x66ilterOriginDomain\x12\x45\n\x10\x66ilter_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66ilterTimestamp\x12\x36\n\x17\x66ilter_submitting_party\x18\x04 \x01(\tR\x15\x66ilterSubmittingParty\x12\x14\n\x05limit\x18\x05 \x01(\x03R\x05limit\"\x9e\x04\n\x1b\x41\x64minTransferSearchResponse\x12y\n\x07results\x18\x01 \x03(\x0b\x32_.com.digitalasset.canton.admin.participant.v30.AdminTransferSearchResponse.TransferSearchResultR\x07results\x1a\x83\x03\n\x14TransferSearchResult\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12Z\n\x0btransfer_id\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.admin.participant.v30.TransferIdR\ntransferId\x12#\n\rorigin_domain\x18\x03 \x01(\tR\x0coriginDomain\x12#\n\rtarget_domain\x18\x04 \x01(\tR\x0ctargetDomain\x12)\n\x10submitting_party\x18\x05 \x01(\tR\x0fsubmittingParty\x12\x31\n\x15ready_for_transfer_in\x18\x06 \x01(\x08R\x12readyForTransferIn\x12\x46\n\x11target_time_proof\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0ftargetTimeProof2\xb9\x01\n\x0fTransferService\x12\xa5\x01\n\x0eTransferSearch\x12G.com.digitalasset.canton.admin.participant.v30.AdminTransferSearchQuery\x1aJ.com.digitalasset.canton.admin.participant.v30.AdminTransferSearchResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.transfer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_TRANSFERID']._serialized_start=152
  _globals['_TRANSFERID']._serialized_end=259
  _globals['_ADMINTRANSFERSEARCHQUERY']._serialized_start=262
  _globals['_ADMINTRANSFERSEARCHQUERY']._serialized_end=524
  _globals['_ADMINTRANSFERSEARCHRESPONSE']._serialized_start=527
  _globals['_ADMINTRANSFERSEARCHRESPONSE']._serialized_end=1069
  _globals['_ADMINTRANSFERSEARCHRESPONSE_TRANSFERSEARCHRESULT']._serialized_start=682
  _globals['_ADMINTRANSFERSEARCHRESPONSE_TRANSFERSEARCHRESULT']._serialized_end=1069
  _globals['_TRANSFERSERVICE']._serialized_start=1072
  _globals['_TRANSFERSERVICE']._serialized_end=1257
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: PruningSchedule
        def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class GetSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: PruningSchedule
        def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...

class SetParticipantSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: ParticipantPruningSchedule
        def __init__(self, schedule: _Optional[_Union[ParticipantPruningSchedule, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class GetParticipantSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: ParticipantPruningSchedule
        def __init__(self, schedule: _Optional[_Union[ParticipantPruningSchedule, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...

class PruningSchedule(_message.Message):
    __slots__ = ("cron", "max_duration", "retention")
    CRON_FIELD_NUMBER: _ClassVar[int]
    MAX_DURATION_FIELD_NUMBER: _ClassVar[int]
    RETENTION_FIELD_NUMBER: _ClassVar[int]
    cron: str
    max_duration: _duration_pb2.Duration
    retention: _duration_pb2.Duration
    def __init__(self, cron: _Optional[str] = ..., max_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., retention: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ParticipantPruningSchedule(_message.Message):
    __slots__ = ("schedule", "prune_internally_only")
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    PRUNE_INTERNALLY_ONLY_FIELD_NUMBER: _ClassVar[int]
    schedule: PruningSchedule
    prune_internally_only: bool
    def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ..., prune_internally_only: bool = ...) -> None: ...

class ClearSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class SetCron(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("cron",)
        CRON_FIELD_NUMBER: _ClassVar[int]
        cron: str
        def __init__(self, cron: _Optional[str] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class SetMaxDuration(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("max_duration",)
        MAX_DURATION_FIELD_NUMBER: _ClassVar[int]
        max_duration: _duration_pb2.Duration
        def __init__(self, max_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class SetRetention(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("retention",)
        RETENTION_FIELD_NUMBER: _ClassVar[int]
        retention: _duration_pb2.Duration
        def __init__(self, retention: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class LocatePruningTimestamp(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("index",)
        INDEX_FIELD_NUMBER: _ClassVar[int]
        index: int
        def __init__(self, index: _Optional[int] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("timestamp",)
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        timestamp: _timestamp_pb2.Timestamp
        def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class InitIdRequest(_message.Message):
    __slots__ = ("identifier", "fingerprint", "instance")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    fingerprint: str
    instance: str
    def __init__(self, identifier: _Optional[str] = ..., fingerprint: _Optional[str] = ..., instance: _Optional[str] = ...) -> None: ...

class InitIdResponse(_message.Message):
    __slots__ = ("unique_identifier", "instance")
    UNIQUE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_FIELD_NUMBER: _ClassVar[int]
    unique_identifier: str
    instance: str
    def __init__(self, unique_identifier: _Optional[str] = ..., instance: _Optional[str] = ...) -> None: ...

class GetIdResponse(_message.Message):
    __slots__ = ("initialized", "unique_identifier", "instance")
    INITIALIZED_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_FIELD_NUMBER: _ClassVar[int]
    initialized: bool
    unique_identifier: str
    instance: str
    def __init__(self, initialized: bool = ..., unique_identifier: _Optional[str] = ..., instance: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v1 import mediator_response_pb2 as _mediator_response_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MediatorResponse(_message.Message):
    __slots__ = ("request_id", "sender", "local_verdict", "root_hash", "confirming_parties", "domain_id", "view_position")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    LOCAL_VERDICT_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    CONFIRMING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_POSITION_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    sender: str
    local_verdict: _mediator_response_pb2.LocalVerdict
    root_hash: bytes
    confirming_parties: _containers.RepeatedScalarFieldContainer[str]
    domain_id: str
    view_position: ViewPosition
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., sender: _Optional[str] = ..., local_verdict: _Optional[_Union[_mediator_response_pb2.LocalVerdict, _Mapping]] = ..., root_hash: _Optional[bytes] = ..., confirming_parties: _Optional[_Iterable[str]] = ..., domain_id: _Optional[str] = ..., view_position: _Optional[_Union[ViewPosition, _Mapping]] = ...) -> None: ...

class ViewPosition(_message.Message):
    __slots__ = ("position",)
    POSITION_FIELD_NUMBER: _ClassVar[int]
    position: _containers.RepeatedCompositeFieldContainer[MerkleSeqIndex]
    def __init__(self, position: _Optional[_Iterable[_Union[MerkleSeqIndex, _Mapping]]] = ...) -> None: ...

class MerkleSeqIndex(_message.Message):
    __slots__ = ("is_right",)
    IS_RIGHT_FIELD_NUMBER: _ClassVar[int]
    is_right: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, is_right: _Optional[_Iterable[bool]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import value_pb2 as _value_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Command(_message.Message):
    __slots__ = ("create", "exercise", "exercise_by_key", "create_and_exercise")
    CREATE_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_BY_KEY_FIELD_NUMBER: _ClassVar[int]
    CREATE_AND_EXERCISE_FIELD_NUMBER: _ClassVar[int]
    create: CreateCommand
    exercise: ExerciseCommand
    exercise_by_key: ExerciseByKeyCommand
    create_and_exercise: CreateAndExerciseCommand
    def __init__(self, create: _Optional[_Union[CreateCommand, _Mapping]] = ..., exercise: _Optional[_Union[ExerciseCommand, _Mapping]] = ..., exercise_by_key: _Optional[_Union[ExerciseByKeyCommand, _Mapping]] = ..., create_and_exercise: _Optional[_Union[CreateAndExerciseCommand, _Mapping]] = ...) -> None: ...

class CreateCommand(_message.Message):
    __slots__ = ("template_id", "create_arguments")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    create_arguments: _value_pb2.Record
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., create_arguments: _Optional[_Union[_value_pb2.Record, _Mapping]] = ...) -> None: ...

class ExerciseCommand(_message.Message):
    __slots__ = ("template_id", "contract_id", "choice", "choice_argument")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    CHOICE_FIELD_NUMBER: _ClassVar[int]
    CHOICE_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    contract_id: str
    choice: str
    choice_argument: _value_pb2.Value
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., contract_id: _Optional[str] = ..., choice: _Optional[str] = ..., choice_argument: _Optional[_Union[_value_pb2.Value, _Mapping]] = ...) -> None: ...

class ExerciseByKeyCommand(_message.Message):
    __slots__ = ("template_id", "contract_key", "choice", "choice_argument")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_KEY_FIELD_NUMBER: _ClassVar[int]
    CHOICE_FIELD_NUMBER: _ClassVar[int]
    CHOICE_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    contract_key: _value_pb2.Value
    choice: str
    choice_argument: _value_pb2.Value
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., contract_key: _Optional[_Union[_value_pb2.Value, _Mapping]] = ..., choice: _Optional[str] = ..., choice_argument: _Optional[_Union[_value_pb2.Value, _Mapping]] = ...) -> None: ...

class CreateAndExerciseCommand(_message.Message):
    __slots__ = ("template_id", "create_arguments", "choice", "choice_argument")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    CHOICE_FIELD_NUMBER: _ClassVar[int]
    CHOICE_ARGUMENT_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    create_arguments: _value_pb2.Record
    choice: str
    choice_argument: _value_pb2.Value
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., create_arguments: _Optional[_Union[_value_pb2.Record, _Mapping]] = ..., choice: _Optional[str] = ..., choice_argument: _Optional[_Union[_value_pb2.Value, _Mapping]] = ...) -> None: ...

class DisclosedContract(_message.Message):
    __slots__ = ("template_id", "contract_id", "created_event_blob", "domain_id")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    contract_id: str
    created_event_blob: bytes
    domain_id: str
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., contract_id: _Optional[str] = ..., created_event_blob: _Optional[bytes] = ..., domain_id: _Optional[str] = ...) -> None: ...

class Commands(_message.Message):
    __slots__ = ("workflow_id", "application_id", "command_id", "commands", "deduplication_duration", "deduplication_offset", "min_ledger_time_abs", "min_ledger_time_rel", "act_as", "read_as", "submission_id", "disclosed_contracts", "domain_id", "package_id_selection_preference")
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_ABS_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_REL_FIELD_NUMBER: _ClassVar[int]
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    READ_AS_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    DISCLOSED_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_ID_SELECTION_PREFERENCE_FIELD_NUMBER: _ClassVar[int]
    workflow_id: str
    application_id: str
    command_id: str
    commands: _containers.RepeatedCompositeFieldContainer[Command]
    deduplication_duration: _duration_pb2.Duration
    deduplication_offset: int
    min_ledger_time_abs: _timestamp_pb2.Timestamp
    min_ledger_time_rel: _duration_pb2.Duration
    act_as: _containers.RepeatedScalarFieldContainer[str]
    read_as: _containers.RepeatedScalarFieldContainer[str]
    submission_id: str
    disclosed_contracts: _containers.RepeatedCompositeFieldContainer[DisclosedContract]
    domain_id: str
    package_id_selection_preference: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, workflow_id: _Optional[str] = ..., application_id: _Optional[str] = ..., command_id: _Optional[str] = ..., commands: _Optional[_Iterable[_Union[Command, _Mapping]]] = ..., deduplication_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., deduplication_offset: _Optional[int] = ..., min_ledger_time_abs: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., min_ledger_time_rel: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., act_as: _Optional[_Iterable[str]] = ..., read_as: _Optional[_Iterable[str]] = ..., submission_id: _Optional[str] = ..., disclosed_contracts: _Optional[_Iterable[_Union[DisclosedContract, _Mapping]]] = ..., domain_id: _Optional[str] = ..., package_id_selection_preference: _Optional[_Iterable[str]] = ...) -> None: ...
